==> file?get=wackowiki-6.0.38.zip: wackowiki-6.0.38/src/js/lang/wikiedit.nl.js <==
lang = {
	// default.js
	ReallySave :			"Really save?",
	ModifiedHint :			"Field has changed, do not forget to save the changes.",
	NotSavedWarning :		"You did not save changes. Are you sure you want to leave?",
	SessionExpiredEditor :	"Je sessie is verlopen!\nJe bent afgemeld vanwege lange inactiviteit.\n1. Sla je formulier op in een sms-bestand om verlies te voorkomen.\n2. Vernieuw de pagina.\n3. Log opnieuw in en dien opnieuw in.",

	// wikiedit.js
	HelpAbout :				"Help & About",
	HelpFormatting :		"Help",
	HelpFormattingTip :		"Help on Wiki-formatting",
	HelpFormattingPage :	"Doc/English/Formatting",

	Heading1 :				"Niveau 1 kop",
	Heading2 :				"Niveau 2 kop",
	Heading3 :				"Niveau 3 kop",
	Heading4 :				"Niveau 4 kop",
	Heading5 :				"Niveau 5 kop",
	Heading6 :				"Niveau 6 kop",
	Bold :					"Vetgedrukte",
	Italic :				"Cursieve",
	Underline :				"Onderstreepte",
	Strikethrough :			"Doorgestreepte",
	Small :					"Klein",
	Code :					"Code",
	Superscript :			"Superscript",
	Subscript :				"Subscript",
	List :					"Ongeordende lijst",
	NumberedList :			"Geordende lijst",
	Left :					"Links",
	Center :				"Gecentreerd",
	Right :					"Rechts",
	Justify :				"Uitvullen",
	Outdent :				"Uitspringen",
	Indent :				"Inspringen",
	CodeWrapper :			"Code Wrapper",
	HTML :					"HTML",
	Action :				"Action",
	Line :					"Horizontale lijn",
	Signature :				"Handtekening",
	Quote :					"Quote",
	MarkedText :			"Marked text",
	HighlightText :			"Highlight text",
	Shade :					"Shade",
	Footnote :				"Voetnoot",
	Hyperlink :				"Hyperlink",
	InsertTable :			"Tafel invoegen",

	Link :					"Link",
	TextForLinking :		"Text for linking",

	HelpAboutTip :			' Shortcuts:\n'+
							' Ctrl+B - Bold\n'+
							' Ctrl+I - Italic\n'+
							' Ctrl+U - Underline\n'+
							' Ctrl+Shift+S - Strikethrough\n'+
							' Ctrl+Shift+1 .. 4 - Heading 1..4\n'+
							' Alt+I or Ctrl+T - Indent\n'+
							' Alt+U or Ctrl+Shift+T - Unindent\n'+
							' Ctrl+J - MarkUp (!!)\n'+
							' Ctrl+H - MarkUp (??)\n'+
							' Alt+L - Link\n'+
							' Ctrl+L - Link with description\n'+
							' Ctrl+Shift+L - Unordered List\n'+
							' Ctrl+Shift+N - Ordered List\n'+
							' Ctrl+Shift+O - Ordered List\n'+
							' Ctrl+= - Small text\n'+
							' Ctrl+Shift+Minus - Horizontal line\n'+
							' \n'
};

==> file?get=wackowiki-6.2.0.zip: wackowiki-6.2.0/src/js/lang/wikiedit.nl.js <==
lang = {
	// default.js
	ReallySave :			"Echt opslaan?",
	ModifiedHint :			"Het veld is veranderd, vergeet niet de wijzigingen op te slaan.",
	NotSavedWarning :		"U hebt de wijzigingen niet opgeslagen. Weet u zeker dat u deze wilt verlaten?",
	SessionExpiredEditor :	"Je sessie is verlopen!\nJe bent afgemeld vanwege lange inactiviteit.\n1. Sla je formulier op in een sms-bestand om verlies te voorkomen.\n2. Vernieuw de pagina.\n3. Log opnieuw in en dien opnieuw in.",

	// wikiedit.js
	HelpAbout :				"Help & Over",
	HelpFormatting :		"Hulp",
	HelpFormattingTip :		"Help over Wiki-opmaak",
	HelpFormattingPage :	"Doc/English/Formatting",

	Heading1 :				"Niveau 1 kop",
	Heading2 :				"Niveau 2 kop",
	Heading3 :				"Niveau 3 kop",
	Heading4 :				"Niveau 4 kop",
	Heading5 :				"Niveau 5 kop",
	Heading6 :				"Niveau 6 kop",
	Bold :					"Vetgedrukte",
	Italic :				"Cursieve",
	Underline :				"Onderstreepte",
	Strikethrough :			"Doorgestreepte",
	Small :					"Klein",
	Code :					"Code",
	Superscript :			"Superscript",
	Subscript :				"Subscript",
	List :					"Ongeordende lijst",
	NumberedList :			"Geordende lijst",
	Left :					"Links",
	Center :				"Gecentreerd",
	Right :					"Rechts",
	Justify :				"Uitvullen",
	Outdent :				"Uitspringen",
	Indent :				"Inspringen",
	CodeWrapper :			"Code Wrapper",
	HTML :					"HTML",
	Action :				"Actie",
	Line :					"Horizontale lijn",
	Signature :				"Handtekening",
	Quote :					"Offerte",
	MarkedText :			"Gemarkeerde tekst",
	HighlightText :			"Tekst markeren",
	Shade :					"Schaduw",
	Footnote :				"Voetnoot",
	Hyperlink :				"Hyperlink",
	InsertTable :			"Tafel invoegen",

	Link :					"Link",
	TextForLinking :		"Tekst voor linken",

	HelpAboutTip :			' Snelkoppelingen:\n'+
							' Ctrl+B - Vetgedrukt\n'+
							' Ctrl+I - Italic\n'+
							' Ctrl+U - Underline\n'+
							' Ctrl+Shift+S - Strikethrough\n'+
							' Ctrl+Shift+1 .. 4 - Heading 1..4\n'+
							' Alt+I or Ctrl+T - Inspringen\n'+
							' Alt+U or Ctrl+Shift+T - Unindent\n'+
							' Ctrl+J - MarkUp (!!)\n'+
							' Ctrl+H - MarkUp (??)\n'+
							' Alt+L - Link\n'+
							' Ctrl+L - Link with description\n'+
							' Ctrl+Shift+L - Unordered List\n'+
							' Ctrl+Shift+N - Ordered List\n'+
							' Ctrl+Shift+O - Ordered List\n'+
							' Ctrl+= - Kleine tekst\n'+
							' Ctrl+Shift+Minus - Horizontal line\n'+
							' \n'
};
